==> refcomp-entities-0.1-sources.jar: fr/inra/refcomp/entities/Agent.java <==
/*
 * #%L
 * Refcomp :: entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2010 - 2011 Inra
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package fr.inra.refcomp.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;
import org.nuiton.wikitty.entities.BusinessEntity;
import org.nuiton.wikitty.entities.BusinessEntityImpl;
import org.nuiton.wikitty.entities.Wikitty;
import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.WikittyTreeNode;
import org.nuiton.wikitty.entities.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.entities.WikittyTreeNodeImpl;
import org.nuiton.wikitty.entities.WikittyUser;
import org.nuiton.wikitty.entities.WikittyUserAbstract;
import org.nuiton.wikitty.entities.WikittyUserImpl;


public interface Agent extends BusinessEntity, User {     String EXT_AGENT = "Agent";
     String FIELD_AGENT_REFNUMBER = "refNumber";
     String FQ_FIELD_AGENT_REFNUMBER = EXT_AGENT + ".refNumber";
     String FIELD_AGENT_STATE = "state";
     String FQ_FIELD_AGENT_STATE = EXT_AGENT + ".state";
     String FIELD_AGENT_STATEDATE = "stateDate";
     String FQ_FIELD_AGENT_STATEDATE = EXT_AGENT + ".stateDate";
     String FIELD_AGENT_AGENT = "agent";
     String FQ_FIELD_AGENT_AGENT = EXT_AGENT + ".agent";
     String FIELD_AGENT_JOBTYPE = "jobType";
     String FQ_FIELD_AGENT_JOBTYPE = EXT_AGENT + ".jobType";
     String FIELD_AGENT_ADDRESS = "address";
     String FQ_FIELD_AGENT_ADDRESS = EXT_AGENT + ".address";
     String FIELD_AGENT_CATI = "cati";
     String FQ_FIELD_AGENT_CATI = EXT_AGENT + ".cati";
     String FIELD_AGENT_DEPARTMENT = "department";
     String FQ_FIELD_AGENT_DEPARTMENT = EXT_AGENT + ".department";
     String FIELD_AGENT_UNIT = "unit";
     String FQ_FIELD_AGENT_UNIT = EXT_AGENT + ".unit";
    /**
     * getRefNumber :
     * @return String 
     */

     String getRefNumber();

    /**
     * setRefNumber :
     * @param refNumber 
     */

     void setRefNumber(String refNumber);

    /**
     * getState :
     * @return String 
     */

     String getState();

    /**
     * setState :
     * @param state 
     */

     void setState(String state);

    /**
     * getStateDate :
     * @return Date 
     */

     Date getStateDate();

    /**
     * setStateDate :
     * @param stateDate 
     */

     void setStateDate(Date stateDate);

    /**
     * getAgent :
     * @return Boolean 
     */

     Boolean getAgent();

    /**
     * setAgent :
     * @param agent 
     */

     void setAgent(Boolean agent);

    /**
     * getJobType :
     * @return String 
     */

     String getJobType();

    /**
     * setJobType :
     * @param jobType 
     */

     void setJobType(String jobType);

    /**
     * getAddress :
     * @return String 
     */

     String getAddress();

    /**
     * setAddress :
     * @param address 
     */

     void setAddress(String address);

    /**
     * getCati :
     * @return String 
     */

     String getCati();

    /**
     * setCati :
     * @param cati 
     */

     void setCati(String cati);

    /**
     * getDepartment :
     * @return String 
     */

     String getDepartment();

    /**
     * setDepartment :
     * @param department 
     */

     void setDepartment(String department);

    /**
     * getUnit :
     * @return Set<String> 
     */

     Set<String> getUnit();

    /**
     * setUnit :
     * @param unit 
     */

     void setUnit(Set<String> unit);

    /**
     * addAllUnit :
     * @param unit 
     */

     void addAllUnit(Set<String> unit);

    /**
     * addUnit :
     * @param element 
     */

     void addUnit(String element);

    /**
     * removeUnit :
     * @param element 
     */

     void removeUnit(String element);

    /**
     * clearUnit :
     */

     void clearUnit();

    /**
     * getLastName :
     * @return String 
     */

     String getLastName();

    /**
     * setLastName :
     * @param lastName 
     */

     void setLastName(String lastName);

    /**
     * getFirstName :
     * @return String 
     */

     String getFirstName();

    /**
     * setFirstName :
     * @param firstName 
     */

     void setFirstName(String firstName);

    /**
     * getEmail :
     * @return String 
     */

     String getEmail();

    /**
     * setEmail :
     * @param email 
     */

     void setEmail(String email);

    /**
     * getComment :
     * @return String 
     */

     String getComment();

    /**
     * setComment :
     * @param comment 
     */

     void setComment(String comment);

    /**
     * getLogin :
     * @return String 
     */

     String getLogin();

    /**
     * setLogin :
     * @param login 
     */

     void setLogin(String login);

    /**
     * getPassword :
     * @return String 
     */

     String getPassword();

    /**
     * setPassword :
     * @param password 
     */

     void setPassword(String password);


} //Agent

==> refcomp-entities-1.0-sources.jar: fr/inra/refcomp/entities/Agent.java <==
/*
 * #%L
 * Refcomp :: entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2010 - 2011 Inra
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package fr.inra.refcomp.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;
import org.nuiton.wikitty.entities.BusinessEntity;
import org.nuiton.wikitty.entities.BusinessEntityImpl;
import org.nuiton.wikitty.entities.Wikitty;
import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.WikittyTreeNode;
import org.nuiton.wikitty.entities.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.entities.WikittyTreeNodeImpl;
import org.nuiton.wikitty.entities.WikittyUser;
import org.nuiton.wikitty.entities.WikittyUserAbstract;
import org.nuiton.wikitty.entities.WikittyUserImpl;


public interface Agent extends BusinessEntity, User {     String EXT_AGENT = "Agent";
     String FIELD_AGENT_REFNUMBER = "refNumber";
     String FQ_FIELD_AGENT_REFNUMBER = EXT_AGENT + ".refNumber";
     String FIELD_AGENT_STATE = "state";
     String FQ_FIELD_AGENT_STATE = EXT_AGENT + ".state";
     String FIELD_AGENT_STATEDATE = "stateDate";
     String FQ_FIELD_AGENT_STATEDATE = EXT_AGENT + ".stateDate";
     String FIELD_AGENT_AGENT = "agent";
     String FQ_FIELD_AGENT_AGENT = EXT_AGENT + ".agent";
     String FIELD_AGENT_JOBTYPE = "jobType";
     String FQ_FIELD_AGENT_JOBTYPE = EXT_AGENT + ".jobType";
     String FIELD_AGENT_ADDRESS = "address";
     String FQ_FIELD_AGENT_ADDRESS = EXT_AGENT + ".address";
     String FIELD_AGENT_JOBTYPEREFERENCE = "jobTypeReference";
     String FQ_FIELD_AGENT_JOBTYPEREFERENCE = EXT_AGENT + ".jobTypeReference";
     String FIELD_AGENT_PEPI = "pepi";
     String FQ_FIELD_AGENT_PEPI = EXT_AGENT + ".pepi";
     String FIELD_AGENT_CATI = "cati";
     String FQ_FIELD_AGENT_CATI = EXT_AGENT + ".cati";
     String FIELD_AGENT_DEPARTMENT = "department";
     String FQ_FIELD_AGENT_DEPARTMENT = EXT_AGENT + ".department";
     String FIELD_AGENT_UNIT = "unit";
     String FQ_FIELD_AGENT_UNIT = EXT_AGENT + ".unit";
    /**
     * getRefNumber :
     * @return String 
     */

     String getRefNumber();

    /**
     * setRefNumber :
     * @param refNumber 
     */

     void setRefNumber(String refNumber);

    /**
     * getState :
     * @return String 
     */

     String getState();

    /**
     * setState :
     * @param state 
     */

     void setState(String state);

    /**
     * getStateDate :
     * @return Date 
     */

     Date getStateDate();

    /**
     * setStateDate :
     * @param stateDate 
     */

     void setStateDate(Date stateDate);

    /**
     * getAgent :
     * @return Boolean 
     */

     Boolean getAgent();

    /**
     * setAgent :
     * @param agent 
     */

     void setAgent(Boolean agent);

    /**
     * getJobType :
     * @return String 
     */

     String getJobType();

    /**
     * setJobType :
     * @param jobType 
     */

     void setJobType(String jobType);

    /**
     * getAddress :
     * @return String 
     */

     String getAddress();

    /**
     * setAddress :
     * @param address 
     */

     void setAddress(String address);

    /**
     * getJobTypeReference :
     * @return String 
     */

     String getJobTypeReference();

    /**
     * setJobTypeReference :
     * @param jobTypeReference 
     */

     void setJobTypeReference(String jobTypeReference);

    /**
     * getPepi :
     * @return String 
     */

     String getPepi();

    /**
     * setPepi :
     * @param pepi 
     */

     void setPepi(String pepi);

    /**
     * getCati :
     * @return String 
     */

     String getCati();

    /**
     * setCati :
     * @param cati 
     */

     void setCati(String cati);

    /**
     * getDepartment :
     * @return String 
     */

     String getDepartment();

    /**
     * setDepartment :
     * @param department 
     */

     void setDepartment(String department);

    /**
     * getUnit :
     * @return Set<String> 
     */

     Set<String> getUnit();

    /**
     * setUnit :
     * @param unit 
     */

     void setUnit(Set<String> unit);

    /**
     * addAllUnit :
     * @param unit 
     */

     void addAllUnit(Set<String> unit);

    /**
     * addUnit :
     * @param element 
     */

     void addUnit(String element);

    /**
     * removeUnit :
     * @param element 
     */

     void removeUnit(String element);

    /**
     * clearUnit :
     */

     void clearUnit();

    /**
     * getLastName :
     * @return String 
     */

     String getLastName();

    /**
     * setLastName :
     * @param lastName 
     */

     void setLastName(String lastName);

    /**
     * getFirstName :
     * @return String 
     */

     String getFirstName();

    /**
     * setFirstName :
     * @param firstName 
     */

     void setFirstName(String firstName);

    /**
     * getEmail :
     * @return String 
     */

     String getEmail();

    /**
     * setEmail :
     * @param email 
     */

     void setEmail(String email);

    /**
     * getComment :
     * @return String 
     */

     String getComment();

    /**
     * setComment :
     * @param comment 
     */

     void setComment(String comment);

    /**
     * getLogin :
     * @return String 
     */

     String getLogin();

    /**
     * setLogin :
     * @param login 
     */

     void setLogin(String login);

    /**
     * getPassword :
     * @return String 
     */

     String getPassword();

    /**
     * setPassword :
     * @param password 
     */

     void setPassword(String password);


} //Agent
